==> haskell-src-exts-util-0.2.5-69-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-src-exts-util.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 haskell-src-exts-util
version:              0.2.5
visibility:           public
id:                   haskell-src-exts-util-0.2.5-1O7h7VSH7l4EFHYweknd6W
key:                  haskell-src-exts-util-0.2.5-1O7h7VSH7l4EFHYweknd6W
license:              BSD-3-Clause
copyright:            All Rights Reserved
maintainer:           pepeiborra@gmail.com
author:               Neil Mitchell, Jose Iborra
homepage:             https://github.com/pepeiborra/haskell-src-exts-util
synopsis:             Helper functions for working with haskell-src-exts trees
description:          Helper functions for working with haskell-src-exts trees.
category:             language
abi:                  cf4f3da1df4254f526448f6008b020cb
exposed:              True
exposed-modules:      Language.Haskell.Exts.Util
hidden-modules:
    Language.Haskell.Exts.Bracket Language.Haskell.Exts.FreeVars
    Language.Haskell.Exts.Util.Internal Paths_haskell_src_exts_util

import-dirs:          /usr/lib/ghc-8.10.1/site-local/haskell-src-exts-util-0.2.5
library-dirs:         /usr/lib/ghc-8.10.1/site-local/haskell-src-exts-util-0.2.5
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-8.10.1/haskell-src-exts-util-0.2.5

hs-libraries:         HShaskell-src-exts-util-0.2.5-1O7h7VSH7l4EFHYweknd6W
depends:
    base-4.14.0.0 containers-0.6.2.1
    data-default-0.7.1.1-KKlNqfYiolkKRrpSgrKBsu
    haskell-src-exts-1.23.1-InQjJWw3CYQJfZDPuLGUzS transformers-0.5.6.2
    uniplate-1.6.12-AhX33D3ve9x2Ab028R0mHS

haddock-interfaces:
    /usr/share/doc/haskell-src-exts-util/html/haskell-src-exts-util.haddock

haddock-html:         /usr/share/doc/haskell-src-exts-util/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-src-exts-util-0.2.5-71-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-src-exts-util.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 haskell-src-exts-util
version:              0.2.5
visibility:           public
id:                   haskell-src-exts-util-0.2.5-IgpuoUiYEB6kGlhEgp6ZW
key:                  haskell-src-exts-util-0.2.5-IgpuoUiYEB6kGlhEgp6ZW
license:              BSD-3-Clause
copyright:            All Rights Reserved
maintainer:           pepeiborra@gmail.com
author:               Neil Mitchell, Jose Iborra
homepage:             https://github.com/pepeiborra/haskell-src-exts-util
synopsis:             Helper functions for working with haskell-src-exts trees
description:          Helper functions for working with haskell-src-exts trees.
category:             language
abi:                  26b932de6b31b5234feb6b1c096843e4
exposed:              True
exposed-modules:      Language.Haskell.Exts.Util
hidden-modules:
    Language.Haskell.Exts.Bracket Language.Haskell.Exts.FreeVars
    Language.Haskell.Exts.Util.Internal Paths_haskell_src_exts_util

import-dirs:          /usr/lib/ghc-8.10.2/site-local/haskell-src-exts-util-0.2.5
library-dirs:         /usr/lib/ghc-8.10.2/site-local/haskell-src-exts-util-0.2.5
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-8.10.2/haskell-src-exts-util-0.2.5

hs-libraries:         HShaskell-src-exts-util-0.2.5-IgpuoUiYEB6kGlhEgp6ZW
depends:
    base-4.14.1.0 containers-0.6.2.1
    data-default-0.7.1.1-EQ1Yxf5cFwlI9vOnhbtBic
    haskell-src-exts-1.23.1-vCmNG3acn3Fm5zlP9UadD transformers-0.5.6.2
    uniplate-1.6.12-HtSfr1rCRhjAXO4m8cbzfp

haddock-interfaces:
    /usr/share/doc/haskell-src-exts-util/html/haskell-src-exts-util.haddock

haddock-html:         /usr/share/doc/haskell-src-exts-util/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
